@@ -32,7 +32,9 @@ lease_sample1 = {
             'created_at': '2017-06-27 15:00:00',
             'updated_at': None,
             'id': '087bc740-6d2d-410b-9d47-c7b2b55a9d36',
-            'resource_type': 'physical:host'
+            'resource_type': 'physical:host',
+            'missing_resources': False,
+            'resources_changed': False
         }
     ],
     'created_at': '2017-06-27 15:00:00',
@@ -67,11 +69,10 @@ lease_sample1 = {
         }
     ],
     'id': '6ee55c78-ac52-41a6-99af-2d2d73bcc466',
-    'action': None,
     'project_id': 'aa45f56901ef45ee95e3d211097c0ea3',
-    'status_reason': None,
     'start_date': '2017-06-27T18:00:00.000000',
-    'trust_id': 'b442a580b9504ababf305bf2b4c49512'
+    'trust_id': 'b442a580b9504ababf305bf2b4c49512',
+    'degraded': False
 }
 
 lease_sample2 = {
@@ -91,7 +92,9 @@ lease_sample2 = {
             'created_at': '2017-06-27 15:00:00',
             'updated_at': None,
             'id': '1b05370e-d92a-452d-80db-89842666b604',
-            'resource_type': 'physical:host'
+            'resource_type': 'physical:host',
+            'missing_resources': False,
+            'resources_changed': False
         }
     ],
     'created_at': '2017-06-27 15:00:00',
@@ -126,11 +129,10 @@ lease_sample2 = {
         }
     ],
     'id': 'ef32abe8-a1f7-4c2f-b5f2-941428848230',
-    'action': None,
     'project_id': 'aa45f56901ef45ee95e3d211097c0ea3',
-    'status_reason': None,
     'start_date': '2017-06-27T18:00:00.000000',
-    'trust_id': 'b442a580b9504ababf305bf2b4c49512'
+    'trust_id': 'b442a580b9504ababf305bf2b4c49512',
+    'degraded': False
 }
 
 host_sample1 = {
@@ -147,7 +149,8 @@ host_sample1 = {
     "local_gb": 128,
     "id": "1",
     "trust_id": "dummy",
-    "ex1": "dummy"
+    "ex1": "dummy",
+    "reservable": True
 }
 
 host_sample2 = {
@@ -164,17 +167,17 @@ host_sample2 = {
     "local_gb": 128,
     "id": "2",
     "trust_id": "dummy",
-    "ex2": "dummy"
+    "ex2": "dummy",
+    "reservable": True
 }
 
 
-class DummyNovaHost(object):
-    def __init__(self, host_name, service):
-        self.host_name = host_name
-        self.service = service
+class DummyHypervisor(object):
+    def __init__(self, host_name):
+        self.hypervisor_hostname = host_name
 
-novahost_sample1 = DummyNovaHost('compute-1', 'compute')
-novahost_sample2 = DummyNovaHost('compute-2', 'compute')
+hypervisor_sample1 = DummyHypervisor('compute-1')
+hypervisor_sample2 = DummyHypervisor('compute-2')
 
 
 def data(TEST):
@@ -188,7 +191,7 @@ def data(TEST):
     TEST.hosts.add(api.client.Host(host_sample1))
     TEST.hosts.add(api.client.Host(host_sample2))
 
-    TEST.novahosts = utils.TestDataContainer()
+    TEST.hypervisors = utils.TestDataContainer()
 
-    TEST.novahosts.add(novahost_sample1)
-    TEST.novahosts.add(novahost_sample2)
+    TEST.hypervisors.add(hypervisor_sample1)
+    TEST.hypervisors.add(hypervisor_sample2)
